pub unsafe extern "C" fn ppl_Generator_divisor(
g: ppl_const_Generator_t,
n: ppl_Coefficient_t,
) -> c_intExpand description
\relates ppl_Generator_tag \brief If \p g is a point or a closure point assigns its divisor to \p n.
pub unsafe extern "C" fn ppl_Generator_divisor(
g: ppl_const_Generator_t,
n: ppl_Coefficient_t,
) -> c_int\relates ppl_Generator_tag \brief If \p g is a point or a closure point assigns its divisor to \p n.