pub unsafe extern "C" fn ppl_delete_Coefficient(
c: ppl_const_Coefficient_t,
) -> c_intExpand description
\relates ppl_Coefficient_tag \brief Invalidates the handle \p c: this makes sure the corresponding resources will eventually be released.
pub unsafe extern "C" fn ppl_delete_Coefficient(
c: ppl_const_Coefficient_t,
) -> c_int\relates ppl_Coefficient_tag \brief Invalidates the handle \p c: this makes sure the corresponding resources will eventually be released.