pub unsafe extern "C" fn ppl_delete_Generator(
g: ppl_const_Generator_t,
) -> c_intExpand description
\relates ppl_Generator_tag \brief Invalidates the handle \p g: this makes sure the corresponding resources will eventually be released.
pub unsafe extern "C" fn ppl_delete_Generator(
g: ppl_const_Generator_t,
) -> c_int\relates ppl_Generator_tag \brief Invalidates the handle \p g: this makes sure the corresponding resources will eventually be released.