pub unsafe extern "C" fn ppl_new_Generator_System(
pgs: *mut ppl_Generator_System_t,
) -> c_intExpand description
\relates ppl_Generator_System_tag \brief Builds an empty system of generators and writes a handle to it at address \p pgs.
pub unsafe extern "C" fn ppl_new_Generator_System(
pgs: *mut ppl_Generator_System_t,
) -> c_int\relates ppl_Generator_System_tag \brief Builds an empty system of generators and writes a handle to it at address \p pgs.