pub unsafe extern "C" fn ppl_new_Generator(
pg: *mut ppl_Generator_t,
le: ppl_const_Linear_Expression_t,
t: ppl_enum_Generator_Type,
d: ppl_const_Coefficient_t,
) -> c_intExpand description
\relates ppl_Generator_tag \brief Creates a new generator of direction \p le and type \p t. If the generator to be created is a point or a closure point, the divisor \p d is applied to \p le. For other types of generators \p d is simply disregarded. A handle for the new generator is written at address \p pg. The space dimension of the new generator is equal to the space dimension of \p le.