pub unsafe extern "C" fn ppl_thread_finalize() -> c_intExpand description
\brief Performs thread specific finalization for the Parma Polyhedra Library.
This function must be called after any other library function whenever
terminating a new thread. It should not be called by the main
thread, since this is finalized by calling ppl_finalize().
\return
PPL_ERROR_INVALID_ARGUMENT if the thread
was already finalized.