pub unsafe extern "C" fn ppl_thread_initialize() -> c_intExpand description
\brief Performs thread specific initialization for the Parma Polyhedra Library.
This function must be called before any other function whenever
starting a new thread. The main thread is already
initialized by the call to ppl_initialize().
\return
PPL_ERROR_INVALID_ARGUMENT if the thread
was already initialized.