pub type ppl_Coefficient_t = *mut ppl_Coefficient_tag;Expand description
\interface ppl_Coefficient_tag \brief Types and functions for coefficients.
The types and functions for coefficients provide an interface towards \extref{Parma_Polyhedra_Library::Coefficient, Coefficient}. Depending on configuration, the PPL coefficients may be implemented by the unbounded precision integers provided by GMP (default), or by bounded precision integers (with checks for overflows).